@@ -86,12 +86,17 @@ battstat_upower_initialise (void (*callback) (void))
   GCancellable *cancellable = g_cancellable_new();
   GError *gerror;
 
+#if !UP_CHECK_VERSION(0, 99, 0)
   if (! up_client_enumerate_devices_sync( upc, cancellable, &gerror ) ) {
     sprintf(error_str, "Unable to enumerate upower devices: %s\n", gerror->message);
     goto error_shutdownclient;
   }
-
+#endif
+#if UP_CHECK_VERSION(0, 99, 0)
+  g_signal_connect_after( upc, "notify", device_cb, NULL );
+#else
   g_signal_connect_after( upc, "device-changed", device_cb, NULL );
+#endif
   g_signal_connect_after( upc, "device-added", device_cb, NULL );
   g_signal_connect_after( upc, "device-removed", device_cb, NULL );
 
@@ -320,9 +325,15 @@ error_dialog( const char *fmt , ...)
   dialog = gtk_message_dialog_new( NULL, 0, GTK_MESSAGE_ERROR,
                                    GTK_BUTTONS_OK, "%s", str);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  g_signal_connect_swapped( G_OBJECT (dialog), "response",
+                            G_CALLBACK (gtk_widget_destroy),
+                            G_OBJECT (dialog) );
+#else
   g_signal_connect_swapped( GTK_OBJECT (dialog), "response",
                             G_CALLBACK (gtk_widget_destroy),
                             GTK_OBJECT (dialog) );
+#endif
 
   gtk_widget_show_all( dialog );
 }
