@@ -79,7 +79,11 @@ static void
 change_background (MatePanelApplet               *applet,
 		   MatePanelAppletBackgroundType  type,
 		   GdkColor                  *colour,
+#if GTK_CHECK_VERSION (3, 0, 0)
+		   cairo_pattern_t           *pattern,
+#else
 		   GdkPixmap                 *pixmap,
+#endif
 		   DriveList                 *drivelist)
 {
     switch (type) {
@@ -127,7 +131,7 @@ display_help (GtkAction *action,
     GError *error = NULL;
 
     gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (drive_list)),
-		"ghelp:drivemount?drivemount",
+		"help:mate-drivemount/drivemount",
 		gtk_get_current_event_time (),
 		&error);
 
