@@ -30,9 +30,14 @@ static void
 applet_back_change (MatePanelApplet			*a,
 		    MatePanelAppletBackgroundType	type,
 		    GdkColor			*color,
+#if GTK_CHECK_VERSION (3, 0, 0)
+		    cairo_pattern_t		*pattern,
+#else
 		    GdkPixmap			*pixmap,
+#endif
 		    EyesApplet			*eyes_applet) 
 {
+#if !GTK_CHECK_VERSION (3, 0, 0)
         /* taken from the TrashApplet */
         GtkRcStyle *rc_style;
         GtkStyle *style;
@@ -66,7 +71,7 @@ applet_back_change (MatePanelApplet			*a,
                 default:
                         break;
         }
-
+#endif
 }
 
 /* TODO - Optimize this a bit */
@@ -298,7 +303,11 @@ create_eyes (MatePanelApplet *applet)
 }
 
 static void
+#if GTK_CHECK_VERSION (3, 0, 0)
+dispose_cb (GObject *object, EyesApplet *eyes_applet)
+#else
 destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
+#endif
 {
 	g_return_if_fail (eyes_applet);
 
@@ -342,7 +351,7 @@ help_cb (GtkAction  *action,
 	GError *error = NULL;
 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
-		"ghelp:geyes",
+		"help:mate-geyes",
 		gtk_get_current_event_time (),
 		&error);
 
@@ -401,7 +410,11 @@ geyes_applet_fill (MatePanelApplet *applet)
         eyes_applet = create_eyes (applet);
 
         eyes_applet->timeout_id = g_timeout_add (
+#if GTK_CHECK_VERSION (3, 0, 0)
+		UPDATE_TIMEOUT, (GSourceFunc) timer_cb, eyes_applet);
+#else
 		UPDATE_TIMEOUT, (GtkFunction) timer_cb, eyes_applet);
+#endif
 
 	action_group = gtk_action_group_new ("Geyes Applet Actions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -432,8 +445,13 @@ geyes_applet_fill (MatePanelApplet *applet)
 			  G_CALLBACK (applet_back_change),
 			  eyes_applet);
 	g_signal_connect (eyes_applet->vbox,
+#if GTK_CHECK_VERSION (3, 0, 0)
+			  "dispose",
+			  G_CALLBACK (dispose_cb),
+#else
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
+#endif
 			  eyes_applet);
 
 	gtk_widget_show_all (GTK_WIDGET (eyes_applet->applet));
