@@ -26,6 +26,9 @@
 #include <mate-panel-applet-gsettings.h>
 
 #include <gdk/gdkkeysyms.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -60,7 +63,7 @@ static void help_cb (GtkAction      *action,
     GError *error = NULL;
 
     gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
-		"ghelp:mateweather",
+		"help:mateweather",
 		gtk_get_current_event_time (),
 		&error);
 
@@ -340,7 +343,11 @@ void mateweather_applet_create (MateWeatherApplet *gw_applet)
                        G_CALLBACK(size_allocate_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
                        G_CALLBACK (applet_destroy), gw_applet);
+#if GTK_CHECK_VERSION (3, 0, 0)
+    g_signal_connect (G_OBJECT(gw_applet->applet), "button_press_event",
+#else
     g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
+#endif
                        G_CALLBACK(clicked_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",           
 			G_CALLBACK(key_press_cb), gw_applet);
