@@ -21,9 +21,18 @@
 #include <libxml/parser.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
-#include <libmatewnck/libmatewnck.h>
+#include <gtk/gtk.h>
+#define WNCK_I_KNOW_THIS_IS_UNSTABLE 1
+#include <libwnck/libwnck.h>
 #include <string.h>
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gtksourceview/gtksource.h>
+#else
+#include <gtksourceview/gtksourceview.h>
+#include <gtksourceview/gtksourcebuffer.h>
+#endif
+
 #include "stickynotes.h"
 #include "stickynotes_callbacks.h"
 #include "util.h"
@@ -36,7 +45,7 @@ static gboolean save_scheduled = FALSE;
 
 static void response_cb (GtkWidget *dialog, gint id, gpointer data);
 
-/* Based on a function found in matewnck */
+/* Based on a function found in wnck */
 static void
 set_icon_geometry  (GdkWindow *window,
                   int        x,
@@ -45,7 +54,11 @@ set_icon_geometry  (GdkWindow *window,
                   int        height)
 {
       gulong data[4];
+#if GTK_CHECK_VERSION (3, 0, 0)
+      Display *dpy = gdk_x11_display_get_xdisplay (gdk_window_get_display (window));
+#else
       Display *dpy = gdk_x11_drawable_get_xdisplay (window);
+#endif
 
       data[0] = x;
       data[1] = y;
@@ -55,7 +68,11 @@ set_icon_geometry  (GdkWindow *window,
       XChangeProperty (dpy,
                        GDK_WINDOW_XID (window),
                        gdk_x11_get_xatom_by_name_for_display (
+#if GTK_CHECK_VERSION (3, 0, 0)
+			       gdk_window_get_display (window),
+#else
 			       gdk_drawable_get_display (window),
+#endif
 			       "_NET_WM_ICON_GEOMETRY"),
 		       XA_CARDINAL, 32, PropModeReplace,
                        (guchar *)&data, 4);
@@ -113,6 +130,8 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	note->w_lock = GTK_WIDGET (gtk_builder_get_object (builder, "lock_button"));
 	gtk_widget_add_events (note->w_lock, GDK_BUTTON_PRESS_MASK);
 
+	note->buffer = GTK_SOURCE_BUFFER(gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->w_body)));
+
 	note->w_close = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
 	gtk_widget_add_events (note->w_close, GDK_BUTTON_PRESS_MASK);
 	note->w_resize_se = GTK_WIDGET (gtk_builder_get_object (builder, "resize_se_box"));
@@ -369,7 +388,7 @@ response_cb (GtkWidget *dialog, gint id, gpointer data)
 {
         if (id == GTK_RESPONSE_HELP)
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-				"ghelp:stickynotes_applet?stickynotes-settings-individual",
+				"help:mate-stickynotes_applet/stickynotes-settings-individual",
 				gtk_get_current_event_time (),
 				NULL);
         else if (id == GTK_RESPONSE_CLOSE)
@@ -484,10 +503,12 @@ stickynote_set_color (StickyNote  *note,
 		gdk_color_parse ("black", &colors[4]);
 		gdk_color_parse ("white", &colors[5]);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 		/* Allocate these colors */
 		gdk_colormap_alloc_colors (gtk_widget_get_colormap (
 					note->w_window),
 				colors, 6, FALSE, TRUE, success);
+#endif
 
 		/* Apply colors to style */
 		rc_style->base[GTK_STATE_NORMAL] = colors[0];
@@ -639,23 +660,23 @@ stickynote_set_visible (StickyNote *note, gboolean visible)
 		else if (note->workspace > 0)
 		{
 #if 0
-			MatewnckWorkspace *matewnck_ws;
+			WnckWorkspace *wnck_ws;
 			gulong xid;
-			MatewnckWindow *matewnck_win;
-			MatewnckScreen *matewnck_screen;
+			WnckWindow *wnck_win;
+			WnckScreen *wnck_screen;
 
 			g_print ("set_visible(): workspace = %i\n",
 					note->workspace);
 
 			xid = GDK_WINDOW_XID (note->w_window->window);
-			matewnck_screen = matewnck_screen_get_default ();
-			matewnck_win = matewnck_window_get (xid);
-			matewnck_ws = matewnck_screen_get_workspace (
-					matewnck_screen,
+			wnck_screen = wnck_screen_get_default ();
+			wnck_win = wnck_window_get (xid);
+			wnck_ws = wnck_screen_get_workspace (
+					wnck_screen,
 					note->workspace - 1);
-			if (matewnck_win && matewnck_ws)
-				matewnck_window_move_to_workspace (
-						matewnck_win, matewnck_ws);
+			if (wnck_win && wnck_ws)
+				wnck_window_move_to_workspace (
+						wnck_win, wnck_ws);
 			else
 				g_print ("set_visible(): errr\n");
 #endif
@@ -722,7 +743,7 @@ void stickynotes_remove(StickyNote *note)
 gboolean
 stickynotes_save_now (void)
 {
-	MatewnckScreen *matewnck_screen;
+	WnckScreen *wnck_screen;
 	const gchar *title;
 	GtkTextBuffer *buffer;
 	GtkTextIter start, end;
@@ -737,12 +758,12 @@ stickynotes_save_now (void)
 	xmlDocSetRootElement(doc, root);
 	xmlNewProp(root, XML_CHAR("version"), XML_CHAR (VERSION));
 
-	matewnck_screen = matewnck_screen_get_default ();
-	matewnck_screen_force_update (matewnck_screen);
+	wnck_screen = wnck_screen_get_default ();
+	wnck_screen_force_update (wnck_screen);
 
 	/* For all sticky notes */
 	for (i = 0; i < g_list_length(stickynotes->notes); i++) {
-		MatewnckWindow *matewnck_win;
+		WnckWindow *wnck_win;
 		gulong xid = 0;
 
 		/* Access the current note in the list */
@@ -757,13 +778,13 @@ stickynotes_save_now (void)
 		gchar *y_str = g_strdup_printf("%d", note->y);
 
 		xid = GDK_WINDOW_XID (gtk_widget_get_window (note->w_window));
-		matewnck_win = matewnck_window_get (xid);
+		wnck_win = wnck_window_get (xid);
 
 		if (!g_settings_get_boolean (stickynotes->settings, "sticky") &&
-			matewnck_win)
+			wnck_win)
 			note->workspace = 1 +
-				matewnck_workspace_get_number (
-				matewnck_window_get_workspace (matewnck_win));
+				wnck_workspace_get_number (
+				wnck_window_get_workspace (wnck_win));
 		else
 			note->workspace = 0;
 
@@ -852,7 +873,7 @@ stickynotes_load (GdkScreen *screen)
 	xmlDocPtr doc = NULL;
 	xmlNodePtr root;
 	xmlNodePtr node;
-	/* MatewnckScreen *matewnck_screen; */
+	/* WnckScreen *wnck_screen; */
 	GList *new_notes, *tmp1;  /* Lists of StickyNote*'s */
 	GList *new_nodes; /* Lists of xmlNodePtr's */
 	int x, y, w, h;
@@ -1040,8 +1061,8 @@ stickynotes_load (GdkScreen *screen)
 
 	tmp1 = new_notes;
 	/*
-	matewnck_screen = matewnck_screen_get_default ();
-	matewnck_screen_force_update (matewnck_screen);
+	wnck_screen = wnck_screen_get_default ();
+	wnck_screen_force_update (wnck_screen);
 	*/
 
 	while (tmp1)
