@@ -33,7 +33,11 @@ void applet_size_allocate_cb(GtkWidget *widget, GtkAllocation *allocation, Stick
 void applet_change_bg_cb (MatePanelApplet *mate_panel_applet,
 				 MatePanelAppletBackgroundType type,
 				 GdkColor *color,
+#if GTK_CHECK_VERSION (3, 0, 0)
+                     		 cairo_pattern_t *pattern,
+#else
                      		 GdkPixmap *pixmap,
+#endif
                      		 StickyNotesApplet *applet);
 void applet_destroy_cb (MatePanelApplet *mate_panel_applet, StickyNotesApplet *applet);
 /* Callbacks for sticky notes applet menu */
